@@ -223,13 +223,17 @@ for i in range(1, 13):
 # Contracted Inventory information
 
 inv_master_df = data_combined(True)
-inv_dict_df, inv_dict_df_future, inv_dict_fy_2022, inv_dict_fy_2023 = data_dict(master_df)
+inv_dict_df, inv_dict_df_future, inv_dict_fy_2022, inv_dict_fy_2023 = data_dict(inv_master_df)
+
+inv_gen_dict = fixing_generalised_logic(inv_dict_df, inv_master_df, ssp_df)
+inv_wacgu_dict = wacgu(inv_gen_dict)
+inv_last_buy_price = get_last_buy_price(inv_master_df)
 
 
 # main wrapper function
 
 def main_execute():
-    print('Package run 31 executing...')
+    print('Package run 34 executing...')
 
     # collect the base tables
     base_table_2020, base_table_2020_Inv, base_table_2020_Deal = processor(dict_df, master_df, ssp_df, wacgu_dict,
@@ -243,15 +247,19 @@ def main_execute():
                                                                            FY_YEAR[3], month_dict)
 
     # Contracted Inventory information
-    inv_base_table_2020, inv_base_table_2020_Inv, inv_base_table_2020_Deal = processor(inv_dict_df, inv_master_df, ssp_df, wacgu_dict,
-                                                                           FY_YEAR[0], month_dict)
-    inv_base_table_2021, inv_base_table_2021_Inv, inv_base_table_2021_Deal = processor(inv_dict_df_future, inv_master_df, ssp_df,
-                                                                           wacgu_dict,
-                                                                           FY_YEAR[1], month_dict)
-    inv_base_table_2022, inv_base_table_2022_Inv, inv_base_table_2022_Deal = processor(inv_dict_fy_2022, inv_master_df, ssp_df, wacgu_dict,
-                                                                           FY_YEAR[2], month_dict)
-    inv_base_table_2023, inv_base_table_2023_Inv, inv_base_table_2023_Deal = processor(inv_dict_fy_2023, inv_master_df, ssp_df, wacgu_dict,
-                                                                           FY_YEAR[3], month_dict)
+    inv_base_table_2020, inv_base_table_2020_Inv, inv_base_table_2020_Deal = processor(inv_dict_df, inv_master_df,
+                                                                                       ssp_df, inv_wacgu_dict,
+                                                                                       FY_YEAR[0], month_dict)
+    inv_base_table_2021, inv_base_table_2021_Inv, inv_base_table_2021_Deal = processor(inv_dict_df_future,
+                                                                                       inv_master_df, ssp_df,
+                                                                                       inv_wacgu_dict,
+                                                                                       FY_YEAR[1], month_dict)
+    inv_base_table_2022, inv_base_table_2022_Inv, inv_base_table_2022_Deal = processor(inv_dict_fy_2022, inv_master_df,
+                                                                                       ssp_df, inv_wacgu_dict,
+                                                                                       FY_YEAR[2], month_dict)
+    inv_base_table_2023, inv_base_table_2023_Inv, inv_base_table_2023_Deal = processor(inv_dict_fy_2023, inv_master_df,
+                                                                                       ssp_df, inv_wacgu_dict,
+                                                                                       FY_YEAR[3], month_dict)
 
     # Generate base tables
 
